@@ -123,7 +123,7 @@ SEXP GPDPMIX(SEXP Ymat, SEXP Otrend, SEXP Oseas, SEXP o_gp_mod, SEXP o_jitter,
  
     // Set random number generator state
     RNGScope scope; /* Rcpp */
-    arma_rng::set_seed_random(); /* arma */
+    //arma_rng::set_seed_random(); /* arma */
 
     // Initialize SAMPLED parameter values   
     /* cluster capture variables */
@@ -144,8 +144,8 @@ SEXP GPDPMIX(SEXP Ymat, SEXP Otrend, SEXP Oseas, SEXP o_gp_mod, SEXP o_jitter,
     {
 	     pos	               = find(s == m);
 	     num(m)              = pos.n_elem;
-          //num_ht(m)           = sum(1/ipr(pos));
-          num_ht(m)           = sum(1/ipr_dummy(pos));
+       //num_ht(m)           = sum(1/ipr(pos));
+       num_ht(m)           = sum(1/ipr_dummy(pos));
     }   
     /* cluster locations, theta_star */
     NumericVector _theta_vec            = rgamma( (P*M), a, (1/b) );
